import request from '@/utils/request'

// 查询cps_usr_apply与会申请列表
export function listUsrApply(query) {
  return request({
    url: '/cp/usrApply/list',
    method: 'get',
    params: query
  })
}

// 查询cps_usr_apply与会申请详细
export function getUsrApply(id) {
  return request({
    url: '/cp/usrApply/' + id,
    method: 'get'
  })
}

// 新增cps_usr_apply与会申请
export function addUsrApply(data) {
  return request({
    url: '/cp/usrApply',
    method: 'post',
    data: data
  })
}

// 修改cps_usr_apply与会申请
export function updateUsrApply(data) {
  return request({
    url: '/cp/usrApply',
    method: 'put',
    data: data
  })
}
export function rejectUsrApply(data) {
  return request({
    url: '/cp/usrApply/reject',
    method: 'put',
    data: data
  })
}


// 删除cps_usr_apply与会申请
export function delUsrApply(id) {
  return request({
    url: '/cp/usrApply/' + id,
    method: 'delete'
  })
}
